<?php
session_start();
// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 包含数据库连接
require_once '../config.php';

// 初始化参数
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '2024-01-01';
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$product_id = isset($_GET['product_id']) ? $_GET['product_id'] : '';
$customer_id = isset($_GET['customer_id']) ? $_GET['customer_id'] : '';

// 初始化错误和数据变量
$error = '';
$profitData = [];
$totalRevenue = 0;
$totalCost = 0;
$totalProfit = 0;
$grossMargin = 0;
$netMargin = 0;
$products = [];
$customers = [];
$monthlySalesData = [];
$productProfitData = [];

try {
    // 检查必要的表是否存在
    $tables = ['sales_orders', 'sales_order_items', 'products', 'customers'];
    foreach ($tables as $table) {
        $stmt = $pdo->prepare("SHOW TABLES LIKE ?");
        $stmt->execute([$table]);
        if ($stmt->rowCount() == 0) {
            throw new Exception("表 $table 不存在。");
        }
    }

    // 检查product_costs表是否存在，不存在则创建
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'product_costs'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        try {
            // 创建产品成本表
            $pdo->exec("
                CREATE TABLE IF NOT EXISTS `product_costs` (
                    `id` INT AUTO_INCREMENT PRIMARY KEY,
                    `product_id` INT NOT NULL,
                    `calculation_date` DATE NOT NULL,
                    `material_cost` DECIMAL(10,2) NOT NULL DEFAULT 0,
                    `labor_cost` DECIMAL(10,2) NOT NULL DEFAULT 0,
                    `overhead_cost` DECIMAL(10,2) NOT NULL DEFAULT 0,
                    `packaging_cost` DECIMAL(10,2) NOT NULL DEFAULT 0,
                    `other_cost` DECIMAL(10,2) NOT NULL DEFAULT 0,
                    `total_cost` DECIMAL(10,2) NOT NULL,
                    `cost_per_unit` DECIMAL(10,2) NOT NULL,
                    `notes` TEXT,
                    `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP,
                    `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                    UNIQUE KEY `uk_product_id` (`product_id`)
                ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
            ");

            // 为所有成品产品创建默认成本记录
            // 默认成本设置为零或者标准价格的70%（如果有）
            $pdo->exec("
                INSERT INTO product_costs (
                    product_id, 
                    calculation_date, 
                    total_cost, 
                    cost_per_unit
                )
                SELECT 
                    id, 
                    CURRENT_DATE, 
                    IFNULL(standard_price * 0.7, 0), 
                    IFNULL(standard_price * 0.7, 0)
                FROM products 
                WHERE type = 'finished'
            ");
        } catch (PDOException $e) {
            error_log("创建product_costs表失败: " . $e->getMessage());
            // 继续执行，但使用替代方法计算成本
        }
    }

    // 检查product_costs表和cost_per_unit字段是否真的存在
    $productCostsExists = false;
    $costPerUnitExists = false;

    try {
        $stmt = $pdo->prepare("SHOW TABLES LIKE 'product_costs'");
        $stmt->execute();
        $productCostsExists = $stmt->rowCount() > 0;

        if ($productCostsExists) {
            $stmt = $pdo->prepare("SHOW COLUMNS FROM product_costs LIKE 'cost_per_unit'");
            $stmt->execute();
            $costPerUnitExists = $stmt->rowCount() > 0;
        }
    } catch (PDOException $e) {
        error_log("检查product_costs表结构失败: " . $e->getMessage());
        $productCostsExists = false;
        $costPerUnitExists = false;
    }

    // 检查销售订单表中是否含有必要字段
    $stmt = $pdo->prepare("SHOW COLUMNS FROM sales_orders");
    $stmt->execute();
    $columns = $stmt->fetchAll(PDO::FETCH_COLUMN);
    $requiredColumns = ['id', 'order_number', 'customer_id', 'order_date', 'total_amount', 'status'];
    foreach ($requiredColumns as $column) {
        if (!in_array($column, $columns)) {
            throw new Exception("sales_orders 表缺少必要字段: $column");
        }
    }

    // 获取产品列表（用于筛选）
    $stmt = $pdo->prepare("SELECT id, name FROM products ORDER BY name");
    $stmt->execute();
    $products = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取客户列表（用于筛选）
    $stmt = $pdo->prepare("SELECT id, name FROM customers ORDER BY name");
    $stmt->execute();
    $customers = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 修改查询逻辑，根据表和字段是否存在来调整SQL
    if ($productCostsExists && $costPerUnitExists) {
        // 原始SQL查询（使用product_costs表）
        $sql = "
            SELECT 
                p.id AS product_id,
                p.name AS product_name,
                pc.cost_per_unit,
                SUM(soi.quantity) AS total_quantity,
                SUM(soi.unit_price * soi.quantity) AS total_revenue,
                SUM(IFNULL(pc.cost_per_unit, 0) * soi.quantity) AS total_cost
            FROM 
                sales_order_items soi
            JOIN 
                sales_orders so ON soi.sales_order_id = so.id
            JOIN 
                products p ON soi.product_id = p.id
            LEFT JOIN 
                product_costs pc ON p.id = pc.product_id
            WHERE 
                so.status IN ('confirmed', 'processing', 'shipped', 'delivered')
                AND so.order_date BETWEEN :start_date AND :end_date
        ";
    } else {
        // 备用SQL查询（使用products表中的standard_price作为成本估算）
        $sql = "
            SELECT 
                p.id AS product_id,
                p.name AS product_name,
                IFNULL(p.standard_price * 0.7, 0) AS cost_per_unit,
                SUM(soi.quantity) AS total_quantity,
                SUM(soi.unit_price * soi.quantity) AS total_revenue,
                SUM(IFNULL(p.standard_price * 0.7, 0) * soi.quantity) AS total_cost
            FROM 
                sales_order_items soi
            JOIN 
                sales_orders so ON soi.sales_order_id = so.id
            JOIN 
                products p ON soi.product_id = p.id
            WHERE 
                so.status IN ('confirmed', 'processing', 'shipped', 'delivered')
                AND so.order_date BETWEEN :start_date AND :end_date
        ";
    }

    $params = [
        ':start_date' => $start_date,
        ':end_date' => $end_date
    ];

    // 添加筛选条件
    if (!empty($product_id)) {
        $sql .= " AND p.id = :product_id";
        $params[':product_id'] = $product_id;
    }

    if (!empty($customer_id)) {
        $sql .= " AND so.customer_id = :customer_id";
        $params[':customer_id'] = $customer_id;
    }

    if ($productCostsExists && $costPerUnitExists) {
        $sql .= " GROUP BY p.id, p.name, pc.cost_per_unit ORDER BY (SUM(soi.unit_price * soi.quantity) - SUM(IFNULL(pc.cost_per_unit, 0) * soi.quantity)) DESC";
    } else {
        $sql .= " GROUP BY p.id, p.name ORDER BY (SUM(soi.unit_price * soi.quantity) - SUM(IFNULL(p.standard_price * 0.7, 0) * soi.quantity)) DESC";
    }

    // 准备并执行查询
    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $profitData = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 计算利润、毛利率和其他指标
    foreach ($profitData as &$item) {
        $item['total_profit'] = $item['total_revenue'] - $item['total_cost'];
        $item['gross_margin'] = $item['total_revenue'] > 0 ?
            ($item['total_profit'] / $item['total_revenue'] * 100) : 0;
        $item['profit_per_unit'] = $item['total_quantity'] > 0 ?
            ($item['total_profit'] / $item['total_quantity']) : 0;

        // 累计总数
        $totalRevenue += $item['total_revenue'];
        $totalCost += $item['total_cost'];
    }

    // 计算总体指标
    $totalProfit = $totalRevenue - $totalCost;
    $grossMargin = $totalRevenue > 0 ? ($totalProfit / $totalRevenue * 100) : 0;

    // 假设运营成本是总收入的20%（实际应从数据库获取）
    $operatingCosts = $totalRevenue * 0.2;
    $netProfit = $totalProfit - $operatingCosts;
    $netMargin = $totalRevenue > 0 ? ($netProfit / $totalRevenue * 100) : 0;

    // 获取月度销售利润趋势数据
    if ($productCostsExists && $costPerUnitExists) {
        $monthlyTrendSql = "
            SELECT 
                DATE_FORMAT(so.order_date, '%Y-%m') AS month,
                SUM(soi.unit_price * soi.quantity) AS revenue,
                SUM(IFNULL(pc.cost_per_unit, 0) * soi.quantity) AS cost
            FROM 
                sales_orders so
            JOIN 
                sales_order_items soi ON so.id = soi.sales_order_id
            JOIN 
                products p ON soi.product_id = p.id
            LEFT JOIN 
                product_costs pc ON p.id = pc.product_id
            WHERE 
                so.status IN ('confirmed', 'processing', 'shipped', 'delivered')
                AND so.order_date BETWEEN DATE_SUB(:end_date, INTERVAL 11 MONTH) AND :end_date
        ";
    } else {
        $monthlyTrendSql = "
            SELECT 
                DATE_FORMAT(so.order_date, '%Y-%m') AS month,
                SUM(soi.unit_price * soi.quantity) AS revenue,
                SUM(IFNULL(p.standard_price * 0.7, 0) * soi.quantity) AS cost
            FROM 
                sales_orders so
            JOIN 
                sales_order_items soi ON so.id = soi.sales_order_id
            JOIN 
                products p ON soi.product_id = p.id
            WHERE 
                so.status IN ('confirmed', 'processing', 'shipped', 'delivered')
                AND so.order_date BETWEEN DATE_SUB(:end_date, INTERVAL 11 MONTH) AND :end_date
        ";
    }

    if (!empty($product_id)) {
        $monthlyTrendSql .= " AND p.id = :product_id";
    }
    if (!empty($customer_id)) {
        $monthlyTrendSql .= " AND so.customer_id = :customer_id";
    }

    $monthlyTrendSql .= " GROUP BY DATE_FORMAT(so.order_date, '%Y-%m') ORDER BY month";

    $stmt = $pdo->prepare($monthlyTrendSql);
    $trendParams = [
        ':end_date' => $end_date
    ];

    if (!empty($product_id)) {
        $trendParams[':product_id'] = $product_id;
    }
    if (!empty($customer_id)) {
        $trendParams[':customer_id'] = $customer_id;
    }

    $stmt->execute($trendParams);
    $monthlySalesData = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取前10个产品的利润数据（用于图表）
    if ($productCostsExists && $costPerUnitExists) {
        $productProfitSql = "
            SELECT 
                p.name AS product_name,
                SUM(soi.unit_price * soi.quantity) - SUM(IFNULL(pc.cost_per_unit, 0) * soi.quantity) AS profit,
                (SUM(soi.unit_price * soi.quantity) - SUM(IFNULL(pc.cost_per_unit, 0) * soi.quantity)) / SUM(soi.unit_price * soi.quantity) * 100 AS margin
            FROM 
                sales_order_items soi
            JOIN 
                sales_orders so ON soi.sales_order_id = so.id
            JOIN 
                products p ON soi.product_id = p.id
            LEFT JOIN 
                product_costs pc ON p.id = pc.product_id
            WHERE 
                so.status IN ('confirmed', 'processing', 'shipped', 'delivered')
                AND so.order_date BETWEEN :start_date AND :end_date
        ";
    } else {
        $productProfitSql = "
            SELECT 
                p.name AS product_name,
                SUM(soi.unit_price * soi.quantity) - SUM(IFNULL(p.standard_price * 0.7, 0) * soi.quantity) AS profit,
                (SUM(soi.unit_price * soi.quantity) - SUM(IFNULL(p.standard_price * 0.7, 0) * soi.quantity)) / SUM(soi.unit_price * soi.quantity) * 100 AS margin
            FROM 
                sales_order_items soi
            JOIN 
                sales_orders so ON soi.sales_order_id = so.id
            JOIN 
                products p ON soi.product_id = p.id
            WHERE 
                so.status IN ('confirmed', 'processing', 'shipped', 'delivered')
                AND so.order_date BETWEEN :start_date AND :end_date
        ";
    }

    if (!empty($product_id)) {
        $productProfitSql .= " AND p.id = :product_id";
    }
    if (!empty($customer_id)) {
        $productProfitSql .= " AND so.customer_id = :customer_id";
    }

    $productProfitSql .= " GROUP BY p.id, p.name HAVING profit > 0 ORDER BY profit DESC LIMIT 10";

    $stmt = $pdo->prepare($productProfitSql);
    $stmt->execute($params);
    $productProfitData = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    $error = "查询数据时出错: " . $e->getMessage();
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>利润分析 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .dashboard-card {
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 20px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            text-align: center;
        }

        .revenue-card {
            background-color: #e3f2fd;
        }

        .cost-card {
            background-color: #ffebee;
        }

        .profit-card {
            background-color: #e8f5e9;
        }

        .margin-card {
            background-color: #fff8e1;
        }

        .card-title {
            font-size: 16px;
            font-weight: bold;
            margin-bottom: 10px;
        }

        .card-value {
            font-size: 24px;
            font-weight: bold;
        }

        .chart-container {
            height: 350px;
            margin-bottom: 30px;
        }

        .table-responsive {
            margin-top: 20px;
        }

        .filter-section {
            background-color: #f8f9fa;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .profit-positive {
            color: green;
        }

        .profit-negative {
            color: red;
        }

        /* 添加基础表格样式 */
        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }

        table th,
        table td {
            padding: 12px;
            border: 1px solid #ddd;
            text-align: left;
        }

        table th {
            background-color: #f5f5f5;
            font-weight: bold;
        }

        table tr:nth-child(even) {
            background-color: #f9f9f9;
        }

        table tr:hover {
            background-color: #f1f1f1;
        }

        /* 添加容器样式 */
        .container {
            width: 100%;
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        /* 按钮样式 */
        .btn {
            display: inline-block;
            padding: 8px 16px;
            margin: 5px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 14px;
            text-decoration: none;
        }

        .btn:hover {
            background-color: #2980b9;
        }

        .btn-outline-secondary {
            background-color: transparent;
            border: 1px solid #6c757d;
            color: #6c757d;
        }

        .btn-outline-secondary:hover {
            background-color: #6c757d;
            color: white;
        }

        .btn-primary {
            background-color: #0d6efd;
        }

        .btn-primary:hover {
            background-color: #0a58ca;
        }

        /* 表单样式 */
        .form-label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }

        .form-control,
        .form-select {
            width: 100%;
            padding: 8px;
            border: 1px solid #ced4da;
            border-radius: 4px;
            box-sizing: border-box;
        }

        /* 网格系统 */
        .row {
            display: flex;
            flex-wrap: wrap;
            margin-right: -15px;
            margin-left: -15px;
        }

        .col-md-3 {
            flex: 0 0 25%;
            max-width: 25%;
            padding-right: 15px;
            padding-left: 15px;
            box-sizing: border-box;
        }

        .col-md-6 {
            flex: 0 0 50%;
            max-width: 50%;
            padding-right: 15px;
            padding-left: 15px;
            box-sizing: border-box;
        }

        .col-md-12 {
            flex: 0 0 100%;
            max-width: 100%;
            padding-right: 15px;
            padding-left: 15px;
            box-sizing: border-box;
        }

        .col-12 {
            flex: 0 0 100%;
            max-width: 100%;
            padding-right: 15px;
            padding-left: 15px;
            box-sizing: border-box;
        }

        /* 卡片样式 */
        .card {
            position: relative;
            display: flex;
            flex-direction: column;
            min-width: 0;
            word-wrap: break-word;
            background-color: #fff;
            background-clip: border-box;
            border: 1px solid rgba(0, 0, 0, .125);
            border-radius: 8px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, .1);
        }

        .card-header {
            padding: 12px 20px;
            margin-bottom: 0;
            background-color: rgba(0, 0, 0, .03);
            border-bottom: 1px solid rgba(0, 0, 0, .125);
        }

        .card-body {
            flex: 1 1 auto;
            padding: 20px;
        }

        /* 警告样式 */
        .alert {
            position: relative;
            padding: 12px 20px;
            margin-bottom: 16px;
            border: 1px solid transparent;
            border-radius: 4px;
        }

        .alert-danger {
            color: #721c24;
            background-color: #f8d7da;
            border-color: #f5c6cb;
        }

        /* 间距类 */
        .mt-4 {
            margin-top: 1.5rem;
        }

        .g-3 {
            gap: 1rem;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>利润分析</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?php echo $error; ?></div>
        <?php else: ?>
            <!-- 筛选器 -->
            <div class="filter-section">
                <form method="GET" class="row g-3">
                    <div class="col-md-3">
                        <label for="start_date" class="form-label">开始日期</label>
                        <input type="date" class="form-control" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                    </div>
                    <div class="col-md-3">
                        <label for="end_date" class="form-label">结束日期</label>
                        <input type="date" class="form-control" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                    </div>
                    <div class="col-md-3">
                        <label for="product_id" class="form-label">产品</label>
                        <select class="form-select" id="product_id" name="product_id">
                            <option value="">所有产品</option>
                            <?php foreach ($products as $product): ?>
                                <option value="<?php echo $product['id']; ?>" <?php echo ($product['id'] == $product_id) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($product['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="col-md-3">
                        <label for="customer_id" class="form-label">客户</label>
                        <select class="form-select" id="customer_id" name="customer_id">
                            <option value="">所有客户</option>
                            <?php foreach ($customers as $customer): ?>
                                <option value="<?php echo $customer['id']; ?>" <?php echo ($customer['id'] == $customer_id) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($customer['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="col-12">
                        <button type="submit" class="btn btn-primary">应用筛选</button>
                        <a href="profit_analysis.php" class="btn btn-outline-secondary">重置</a>
                    </div>
                </form>
            </div>

            <!-- 关键指标卡片 -->
            <div class="row">
                <div class="col-md-3">
                    <div class="dashboard-card revenue-card">
                        <div class="card-title">总销售额</div>
                        <div class="card-value">¥<?php echo number_format($totalRevenue, 2); ?></div>
                    </div>
                </div>
                <div class="col-md-3">
                    <div class="dashboard-card cost-card">
                        <div class="card-title">总成本</div>
                        <div class="card-value">¥<?php echo number_format($totalCost, 2); ?></div>
                    </div>
                </div>
                <div class="col-md-3">
                    <div class="dashboard-card profit-card">
                        <div class="card-title">总利润</div>
                        <div class="card-value">¥<?php echo number_format($totalProfit, 2); ?></div>
                    </div>
                </div>
                <div class="col-md-3">
                    <div class="dashboard-card margin-card">
                        <div class="card-title">毛利率</div>
                        <div class="card-value"><?php echo number_format($grossMargin, 2); ?>%</div>
                    </div>
                </div>
            </div>

            <!-- 图表部分 -->
            <div class="row">
                <div class="col-md-6">
                    <div class="card">
                        <div class="card-header">
                            月度利润趋势
                        </div>
                        <div class="card-body">
                            <div class="chart-container">
                                <canvas id="monthlyProfitChart"></canvas>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-6">
                    <div class="card">
                        <div class="card-header">
                            产品利润对比
                        </div>
                        <div class="card-body">
                            <div class="chart-container">
                                <canvas id="productProfitChart"></canvas>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row mt-4">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-header">
                            毛利率与净利率对比
                        </div>
                        <div class="card-body">
                            <div class="chart-container">
                                <canvas id="marginComparisonChart"></canvas>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <!-- 详细数据表格 -->
            <div class="card mt-4">
                <div class="card-header">
                    <h5>产品利润详情</h5>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table>
                            <thead>
                                <tr>
                                    <th>产品名称</th>
                                    <th>销售数量</th>
                                    <th>单位成本</th>
                                    <th>销售额</th>
                                    <th>成本总额</th>
                                    <th>利润</th>
                                    <th>单品利润</th>
                                    <th>毛利率</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($profitData as $item): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($item['product_name']); ?></td>
                                        <td><?php echo number_format($item['total_quantity']); ?></td>
                                        <td>¥<?php echo number_format($item['cost_per_unit'] ?? 0, 2); ?></td>
                                        <td>¥<?php echo number_format($item['total_revenue'], 2); ?></td>
                                        <td>¥<?php echo number_format($item['total_cost'], 2); ?></td>
                                        <td class="<?php echo $item['total_profit'] >= 0 ? 'profit-positive' : 'profit-negative'; ?>">
                                            ¥<?php echo number_format($item['total_profit'], 2); ?>
                                        </td>
                                        <td class="<?php echo $item['profit_per_unit'] >= 0 ? 'profit-positive' : 'profit-negative'; ?>">
                                            ¥<?php echo number_format($item['profit_per_unit'], 2); ?>
                                        </td>
                                        <td class="<?php echo $item['gross_margin'] >= 0 ? 'profit-positive' : 'profit-negative'; ?>">
                                            <?php echo number_format($item['gross_margin'], 2); ?>%
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    </div>

    <script>
        // 为图表准备默认的空内容，防止JS错误
        document.addEventListener('DOMContentLoaded', function() {
            try {
                // 检查是否有Canvas元素
                const monthlyChartEl = document.getElementById('monthlyProfitChart');
                const productChartEl = document.getElementById('productProfitChart');
                const marginChartEl = document.getElementById('marginComparisonChart');

                if (!monthlyChartEl || !productChartEl || !marginChartEl) {
                    console.log('未找到图表容器元素');
                    return;
                }

                // 加载Chart.js
                const chartScript = document.createElement('script');
                chartScript.src = 'https://cdn.jsdelivr.net/npm/chart.js@3.7.1/dist/chart.min.js';
                chartScript.onload = function() {
                    // 月度利润趋势图
                    new Chart(monthlyChartEl, {
                        type: 'bar',
                        data: {
                            labels: <?php echo json_encode(array_map(function ($m) {
                                        return $m['month'];
                                    }, $monthlySalesData)); ?>,
                            datasets: [{
                                    label: '销售额',
                                    data: <?php echo json_encode(array_map(function ($m) {
                                                return floatval($m['revenue']);
                                            }, $monthlySalesData)); ?>,
                                    backgroundColor: 'rgba(54, 162, 235, 0.5)',
                                    borderColor: 'rgba(54, 162, 235, 1)',
                                    borderWidth: 1
                                },
                                {
                                    label: '成本',
                                    data: <?php echo json_encode(array_map(function ($m) {
                                                return floatval($m['cost']);
                                            }, $monthlySalesData)); ?>,
                                    backgroundColor: 'rgba(255, 99, 132, 0.5)',
                                    borderColor: 'rgba(255, 99, 132, 1)',
                                    borderWidth: 1
                                },
                                {
                                    label: '利润',
                                    data: <?php echo json_encode(array_map(function ($m) {
                                                return floatval($m['revenue'] - $m['cost']);
                                            }, $monthlySalesData)); ?>,
                                    backgroundColor: 'rgba(75, 192, 192, 0.5)',
                                    borderColor: 'rgba(75, 192, 192, 1)',
                                    borderWidth: 1
                                }
                            ]
                        },
                        options: {
                            responsive: true,
                            maintainAspectRatio: false,
                            scales: {
                                y: {
                                    beginAtZero: true,
                                    title: {
                                        display: true,
                                        text: '金额 (¥)'
                                    }
                                }
                            }
                        }
                    });

                    // 产品利润对比图
                    new Chart(productChartEl, {
                        type: 'bar',
                        data: {
                            labels: <?php echo json_encode(array_map(function ($p) {
                                        return $p['product_name'];
                                    }, $productProfitData)); ?>,
                            datasets: [{
                                label: '利润 (¥)',
                                data: <?php echo json_encode(array_map(function ($p) {
                                            return floatval($p['profit']);
                                        }, $productProfitData)); ?>,
                                backgroundColor: 'rgba(75, 192, 192, 0.7)',
                                borderColor: 'rgba(75, 192, 192, 1)',
                                borderWidth: 1
                            }]
                        },
                        options: {
                            indexAxis: 'y',
                            responsive: true,
                            maintainAspectRatio: false,
                            scales: {
                                x: {
                                    beginAtZero: true,
                                    title: {
                                        display: true,
                                        text: '利润 (¥)'
                                    }
                                }
                            }
                        }
                    });

                    // 毛利率与净利率对比图
                    new Chart(marginChartEl, {
                        type: 'bar',
                        data: {
                            labels: ['总体利润率'],
                            datasets: [{
                                    label: '毛利率',
                                    data: [<?php echo $grossMargin; ?>],
                                    backgroundColor: 'rgba(75, 192, 192, 0.7)',
                                    borderColor: 'rgba(75, 192, 192, 1)',
                                    borderWidth: 1
                                },
                                {
                                    label: '净利率',
                                    data: [<?php echo $netMargin; ?>],
                                    backgroundColor: 'rgba(153, 102, 255, 0.7)',
                                    borderColor: 'rgba(153, 102, 255, 1)',
                                    borderWidth: 1
                                }
                            ]
                        },
                        options: {
                            responsive: true,
                            maintainAspectRatio: false,
                            scales: {
                                y: {
                                    beginAtZero: true,
                                    title: {
                                        display: true,
                                        text: '利润率 (%)'
                                    },
                                    max: 100
                                }
                            }
                        }
                    });
                };
                document.head.appendChild(chartScript);
            } catch (e) {
                console.error('图表初始化失败:', e);
            }
        });
    </script>
</body>

</html>