<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取搜索参数
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$location_id = isset($_GET['location_id']) ? (int)$_GET['location_id'] : 0;
$low_stock_only = isset($_GET['low_stock_only']) ? (bool)$_GET['low_stock_only'] : false;
$price_min = isset($_GET['price_min']) ? (float)$_GET['price_min'] : 0;
$price_max = isset($_GET['price_max']) ? (float)$_GET['price_max'] : 0;

// 获取所有仓库位置
try {
    $stmt = $pdo->query("
        SELECT id, name, type, temperature_controlled, humidity_controlled
        FROM storage_locations
        ORDER BY name
    ");
    $locations = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取仓库位置失败：" . $e->getMessage();
}

// 查询成品库存
try {
    $query = "
        SELECT 
            i.id,
            p.id AS product_id,
            p.name AS product_name,
            p.specification,
            p.description,
            i.quantity_on_hand,
            i.unit,
            i.low_stock_threshold,
            sl.id AS location_id,
            sl.name AS location_name,
            sl.temperature_controlled,
            sl.humidity_controlled,
            i.last_updated,
            p.shelf_life_days,
            p.standard_price
        FROM 
            inventory i
        JOIN 
            products p ON i.product_id = p.id
        JOIN 
            storage_locations sl ON i.storage_location_id = sl.id
        WHERE 
            p.type = 'finished'
    ";

    $params = [];

    // 添加搜索条件
    if (!empty($search)) {
        $query .= " AND (p.name LIKE ? OR p.specification LIKE ? OR p.description LIKE ?)";
        $params[] = "%$search%";
        $params[] = "%$search%";
        $params[] = "%$search%";
    }

    // 按仓库位置筛选
    if ($location_id > 0) {
        $query .= " AND sl.id = ?";
        $params[] = $location_id;
    }

    // 只显示低库存
    if ($low_stock_only) {
        $query .= " AND i.quantity_on_hand <= i.low_stock_threshold AND i.low_stock_threshold > 0";
    }

    // 价格范围筛选
    if ($price_min > 0) {
        $query .= " AND p.standard_price >= ?";
        $params[] = $price_min;
    }

    if ($price_max > 0) {
        $query .= " AND p.standard_price <= ?";
        $params[] = $price_max;
    }

    $query .= " ORDER BY (CASE WHEN i.quantity_on_hand <= i.low_stock_threshold AND i.low_stock_threshold > 0 THEN 0 ELSE 1 END), p.name";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $finishedGoods = $stmt->fetchAll();

    // 对每个成品获取最近的销售订单
    foreach ($finishedGoods as &$product) {
        // 获取该产品最近的销售订单
        $orderQuery = "
            SELECT 
                so.id AS order_id,
                so.order_number,
                so.order_date,
                soi.quantity,
                soi.unit_price,
                soi.discount_rate,
                soi.shipped_quantity,
                c.name AS customer_name,
                so.status
            FROM 
                sales_order_items soi
            JOIN 
                sales_orders so ON soi.sales_order_id = so.id
            JOIN 
                customers c ON so.customer_id = c.id
            WHERE 
                soi.product_id = ?
            ORDER BY 
                so.order_date DESC
            LIMIT 3
        ";

        $orderStmt = $pdo->prepare($orderQuery);
        $orderStmt->execute([$product['product_id']]);
        $product['recent_orders'] = $orderStmt->fetchAll();

        // 获取总销售量
        $totalSalesQuery = "
            SELECT 
                SUM(soi.quantity) AS total_sold
            FROM 
                sales_order_items soi
            JOIN 
                sales_orders so ON soi.sales_order_id = so.id
            WHERE 
                soi.product_id = ?
                AND so.status IN ('confirmed', 'processing', 'partially_shipped', 'shipped', 'delivered')
        ";

        $salesStmt = $pdo->prepare($totalSalesQuery);
        $salesStmt->execute([$product['product_id']]);
        $salesResult = $salesStmt->fetch();
        $product['total_sold'] = $salesResult['total_sold'] ?: 0;
    }
} catch (PDOException $e) {
    $error = "获取成品库存失败：" . $e->getMessage();
}

// 获取最近的出库记录
try {
    $outboundQuery = "
        SELECT 
            sh.id,
            sh.shipment_number,
            sh.shipment_date,
            so.order_number,
            soi.product_id,
            p.name AS product_name,
            soi.quantity AS ordered_quantity,
            soi.shipped_quantity,
            c.name AS customer_name,
            sh.status AS shipment_status
        FROM 
            shipments sh
        JOIN 
            sales_orders so ON sh.sales_order_id = so.id
        JOIN 
            sales_order_items soi ON so.id = soi.sales_order_id
        JOIN 
            products p ON soi.product_id = p.id
        JOIN 
            customers c ON so.customer_id = c.id
        WHERE 
            p.type = 'finished'
            AND sh.shipment_date >= DATE_SUB(CURRENT_DATE, INTERVAL 30 DAY)
        ORDER BY 
            sh.shipment_date DESC
        LIMIT 10
    ";

    $outboundStmt = $pdo->prepare($outboundQuery);
    $outboundStmt->execute();
    $recentOutbound = $outboundStmt->fetchAll();
} catch (PDOException $e) {
    $error_outbound = "获取出库记录失败：" . $e->getMessage();
}

// 订单状态映射
$orderStatusDisplay = [
    'draft' => ['text' => '草稿', 'class' => '待处理'],
    'confirmed' => ['text' => '已确认', 'class' => '进行中'],
    'processing' => ['text' => '处理中', 'class' => '进行中'],
    'partially_shipped' => ['text' => '部分发货', 'class' => '进行中'],
    'shipped' => ['text' => '已发货', 'class' => '已完成'],
    'delivered' => ['text' => '已送达', 'class' => '已完成'],
    'cancelled' => ['text' => '已取消', 'class' => '待处理']
];

// 发货状态映射
$shipmentStatusDisplay = [
    'pending' => ['text' => '待处理', 'class' => '待处理'],
    'ready_to_ship' => ['text' => '待发货', 'class' => '待处理'],
    'shipped' => ['text' => '已发货', 'class' => '进行中'],
    'in_transit' => ['text' => '运输中', 'class' => '进行中'],
    'delivered' => ['text' => '已送达', 'class' => '已完成'],
    'failed' => ['text' => '失败', 'class' => '待处理'],
    'cancelled' => ['text' => '已取消', 'class' => '待处理']
];

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>成品库存管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .container {
            max-width: 1000px;
            margin: 50px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .low-stock {
            background-color: #fff3cd !important;
            color: #856404;
        }

        .search-container {
            display: flex;
            flex-wrap: wrap;
            align-items: center;
            gap: 15px;
            margin-bottom: 20px;
            background-color: #f8f9fa;
            padding: 15px;
            border-radius: 8px;
        }

        .search-container input,
        .search-container select {
            padding: 8px 12px;
            border: 1px solid #ced4da;
            border-radius: 4px;
            flex-grow: 1;
        }

        .search-container button {
            padding: 8px 16px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .search-container button:hover {
            background-color: #2980b9;
        }

        .checkbox-container {
            display: flex;
            align-items: center;
            gap: 5px;
        }

        .checkbox-container input[type="checkbox"] {
            width: auto;
            flex-grow: 0;
        }

        .order-list {
            max-height: 0;
            overflow: hidden;
            transition: max-height 0.3s ease-out;
        }

        .order-list.open {
            max-height: 500px;
        }

        .toggle-orders {
            cursor: pointer;
            color: #3498db;
            user-select: none;
        }

        .toggle-orders:hover {
            text-decoration: underline;
        }

        .toggle-icon {
            margin-left: 5px;
            transition: transform 0.3s;
        }

        .toggle-icon.open {
            transform: rotate(180deg);
        }

        .stock-status {
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            color: white;
        }

        .status-sufficient {
            background-color: #28a745;
        }

        .status-low {
            background-color: #ffc107;
            color: #212529;
        }

        .status-critical {
            background-color: #dc3545;
        }

        .product-description {
            font-size: 0.85em;
            color: #6c757d;
            margin-top: 5px;
            font-style: italic;
        }

        .order-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 12px;
            margin-bottom: 10px;
            background-color: #fff;
        }

        .order-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 8px;
        }

        .order-number {
            font-weight: bold;
            font-size: 14px;
        }

        .order-info {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 8px;
            font-size: 13px;
        }

        .tabs {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #ddd;
        }

        .tab {
            padding: 10px 20px;
            cursor: pointer;
            border-radius: 4px 4px 0 0;
            margin-right: 5px;
        }

        .tab.active {
            background-color: #3498db;
            color: white;
            border: 1px solid #3498db;
            border-bottom: none;
        }

        .tab:not(.active) {
            background-color: #f8f9fa;
            border: 1px solid #ddd;
            border-bottom: none;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .shipment-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 15px;
            background-color: #fff;
        }

        .shipment-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 10px;
        }

        .shipment-number {
            font-weight: bold;
            font-size: 16px;
        }

        .shipment-info {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
        }

        .info-item {
            margin-bottom: 5px;
        }

        .info-label {
            font-weight: bold;
            color: #555;
        }

        .outbound-btn {
            background-color: #28a745;
            color: white;
            padding: 6px 12px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 14px;
            text-decoration: none;
            display: inline-block;
            margin-top: 5px;
        }

        .outbound-btn:hover {
            background-color: #218838;
        }

        .price-filters {
            display: flex;
            align-items: center;
            gap: 10px;
        }

        .price-filters input {
            width: 100px;
        }

        .sales-stats {
            background-color: #e9ecef;
            padding: 5px 8px;
            border-radius: 4px;
            font-size: 12px;
            color: #495057;
            display: flex;
            justify-content: space-between;
            margin-top: 5px;
        }

        .waste-btn {
            background-color: #e74c3c;
            margin-top: 5px;
        }

        .waste-btn:hover {
            background-color: #c0392b;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>成品库存管理</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <!-- 标签页导航 -->
        <div class="tabs">
            <div class="tab active" onclick="switchTab('inventory-tab')">库存一览</div>
            <div class="tab" onclick="switchTab('outbound-tab')">出库记录</div>
        </div>

        <!-- 库存一览标签页 -->
        <div id="inventory-tab" class="tab-content active">
            <!-- 搜索筛选 -->
            <div class="search-container">
                <form method="GET" action="finished_goods_inventory.php">
                    <input type="text" name="search" placeholder="搜索成品名称或规格" value="<?= htmlspecialchars($search) ?>">

                    <select name="location_id">
                        <option value="0">所有仓库位置</option>
                        <?php foreach ($locations as $loc): ?>
                            <option value="<?= $loc['id'] ?>" <?= $location_id == $loc['id'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($loc['name']) ?>
                                <?= $loc['temperature_controlled'] ? ' (温控)' : '' ?>
                                <?= $loc['humidity_controlled'] ? ' (湿控)' : '' ?>
                            </option>
                        <?php endforeach; ?>
                    </select>

                    <div class="price-filters">
                        <input type="number" name="price_min" placeholder="最低价格" value="<?= $price_min > 0 ? $price_min : '' ?>">
                        <span>-</span>
                        <input type="number" name="price_max" placeholder="最高价格" value="<?= $price_max > 0 ? $price_max : '' ?>">
                    </div>

                    <div class="checkbox-container">
                        <input type="checkbox" id="low_stock_only" name="low_stock_only" value="1" <?= $low_stock_only ? 'checked' : '' ?>>
                        <label for="low_stock_only">只显示低库存</label>
                    </div>

                    <button type="submit">筛选</button>
                    <button type="button" onclick="window.location.href='finished_goods_inventory.php'">重置</button>
                </form>
            </div>

            <!-- 成品库存表格 -->
            <div class="table-container">
                <?php if (empty($finishedGoods)): ?>
                    <div class="empty-state">
                        <p>暂无成品库存数据</p>
                    </div>
                <?php else: ?>
                    <table>
                        <thead>
                            <tr>
                                <th>成品名称</th>
                                <th>规格</th>
                                <th>库存数量</th>
                                <th>单位</th>
                                <th>标准售价</th>
                                <th>存放位置</th>
                                <th>库存状态</th>
                                <th>销售情况</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($finishedGoods as $product): ?>
                                <?php
                                $isLowStock = false;
                                $stockStatus = '';
                                $stockStatusClass = '';

                                if ($product['low_stock_threshold'] > 0) {
                                    if ($product['quantity_on_hand'] <= $product['low_stock_threshold'] * 0.5) {
                                        $isLowStock = true;
                                        $stockStatus = '库存紧张';
                                        $stockStatusClass = 'status-critical';
                                    } elseif ($product['quantity_on_hand'] <= $product['low_stock_threshold']) {
                                        $isLowStock = true;
                                        $stockStatus = '库存不足';
                                        $stockStatusClass = 'status-low';
                                    } else {
                                        $stockStatus = '库存充足';
                                        $stockStatusClass = 'status-sufficient';
                                    }
                                } else {
                                    $stockStatus = '未设置预警';
                                    $stockStatusClass = '';
                                }

                                $hasOrders = !empty($product['recent_orders']);
                                ?>
                                <tr class="<?= $isLowStock ? 'low-stock' : '' ?>">
                                    <td>
                                        <?= htmlspecialchars($product['product_name']) ?>
                                        <?php if (!empty($product['description'])): ?>
                                            <div class="product-description"><?= htmlspecialchars($product['description']) ?></div>
                                        <?php endif; ?>
                                    </td>
                                    <td><?= htmlspecialchars($product['specification'] ?? '-') ?></td>
                                    <td><?= number_format($product['quantity_on_hand'], 2) ?></td>
                                    <td><?= htmlspecialchars($product['unit']) ?></td>
                                    <td><?= number_format($product['standard_price'], 2) ?> 元</td>
                                    <td>
                                        <?= htmlspecialchars($product['location_name']) ?>
                                        <?php if ($product['shelf_life_days']): ?>
                                            <div><small>保质期: <?= $product['shelf_life_days'] ?>天</small></div>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <span class="stock-status <?= $stockStatusClass ?>"><?= $stockStatus ?></span>
                                        <?php if ($product['low_stock_threshold'] > 0): ?>
                                            <br>
                                            <small>预警值: <?= $product['low_stock_threshold'] ?> <?= $product['unit'] ?></small>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <div class="sales-stats">
                                            <span>总销量: <?= number_format($product['total_sold'], 2) ?> <?= $product['unit'] ?></span>
                                        </div>

                                        <?php if ($hasOrders): ?>
                                            <div class="toggle-orders" onclick="toggleOrders(this, 'order-list-<?= $product['product_id'] ?>')">
                                                查看最近订单 <span class="toggle-icon">▼</span>
                                            </div>
                                            <div id="order-list-<?= $product['product_id'] ?>" class="order-list">
                                                <?php foreach ($product['recent_orders'] as $order): ?>
                                                    <?php
                                                    $orderStatus = $orderStatusDisplay[$order['status']] ?? ['text' => $order['status'], 'class' => ''];
                                                    $orderTotal = $order['quantity'] * $order['unit_price'] * (1 - $order['discount_rate']);
                                                    ?>
                                                    <div class="order-card">
                                                        <div class="order-header">
                                                            <div class="order-number"><?= htmlspecialchars($order['order_number']) ?></div>
                                                            <div class="status-tag <?= $orderStatus['class'] ?>"><?= $orderStatus['text'] ?></div>
                                                        </div>
                                                        <div class="order-info">
                                                            <div>客户: <?= htmlspecialchars($order['customer_name']) ?></div>
                                                            <div>日期: <?= date('Y-m-d', strtotime($order['order_date'])) ?></div>
                                                            <div>数量: <?= number_format($order['quantity'], 2) ?> <?= $product['unit'] ?></div>
                                                            <div>单价: <?= number_format($order['unit_price'], 2) ?> 元</div>
                                                            <div>已发货: <?= number_format($order['shipped_quantity'], 2) ?> <?= $product['unit'] ?></div>
                                                            <div>总金额: <?= number_format($orderTotal, 2) ?> 元</div>
                                                        </div>
                                                    </div>
                                                <?php endforeach; ?>
                                            </div>
                                        <?php else: ?>
                                            <span class="text-muted">暂无订单记录</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <a href="inventory_history.php?product_id=<?= $product['product_id'] ?>" class="btn-link">查看记录</a>

                                        <a href="create_outbound.php?product_id=<?= $product['product_id'] ?>" class="outbound-btn">创建出库</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        </div>

        <!-- 出库记录标签页 -->
        <div id="outbound-tab" class="tab-content">
            <h3>最近30天出库记录</h3>

            <?php if (isset($error_outbound)): ?>
                <div class="alert alert-danger"><?= $error_outbound ?></div>
            <?php endif; ?>

            <?php if (empty($recentOutbound)): ?>
                <div class="empty-state">
                    <p>暂无出库记录</p>
                </div>
            <?php else: ?>
                <?php foreach ($recentOutbound as $shipment): ?>
                    <?php
                    $shipmentStatus = $shipmentStatusDisplay[$shipment['shipment_status']] ?? ['text' => $shipment['shipment_status'], 'class' => ''];
                    ?>
                    <div class="shipment-card">
                        <div class="shipment-header">
                            <div class="shipment-number">发货单号: <?= htmlspecialchars($shipment['shipment_number']) ?></div>
                            <div class="status-tag <?= $shipmentStatus['class'] ?>"><?= $shipmentStatus['text'] ?></div>
                        </div>
                        <div class="shipment-info">
                            <div class="info-item">
                                <span class="info-label">订单编号:</span>
                                <?= htmlspecialchars($shipment['order_number']) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">发货日期:</span>
                                <?= date('Y-m-d H:i', strtotime($shipment['shipment_date'])) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">产品:</span>
                                <?= htmlspecialchars($shipment['product_name']) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">客户:</span>
                                <?= htmlspecialchars($shipment['customer_name']) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">订单数量:</span>
                                <?= number_format($shipment['ordered_quantity'], 2) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">发货数量:</span>
                                <?= number_format($shipment['shipped_quantity'], 2) ?>
                            </div>
                        </div>
                        <div style="text-align: right; margin-top: 10px;">
                            <a href="outbound_detail.php?shipment_id=<?= $shipment['id'] ?>" class="btn-link">查看详情</a>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function toggleOrders(element, orderListId) {
            const orderList = document.getElementById(orderListId);
            const toggleIcon = element.querySelector('.toggle-icon');

            orderList.classList.toggle('open');
            toggleIcon.classList.toggle('open');
        }

        function switchTab(tabId) {
            // 隐藏所有标签页内容
            document.querySelectorAll('.tab-content').forEach(content => {
                content.classList.remove('active');
            });

            // 取消选中所有标签
            document.querySelectorAll('.tab').forEach(tab => {
                tab.classList.remove('active');
            });

            // 显示选中的标签页内容
            document.getElementById(tabId).classList.add('active');

            // 选中对应的标签
            event.currentTarget.classList.add('active');
        }
    </script>
</body>

</html>