<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 检查必要的表是否存在
try {
    // 检查inventory_checks表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'inventory_checks'");
    if ($stmt->rowCount() == 0) {
        header("Location: inventory_check.php");
        exit;
    }

    // 检查inventory_check_items表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'inventory_check_items'");
    if ($stmt->rowCount() == 0) {
        header("Location: inventory_check.php");
        exit;
    }
} catch (PDOException $e) {
    $error = "检查数据表失败：" . $e->getMessage();
}

// 初始化变量
$error = '';
$check_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($check_id <= 0) {
    header("Location: inventory_check.php");
    exit;
}

// 获取盘点记录主信息
try {
    $stmt = $pdo->prepare("
        SELECT 
            ic.*,
            sl.name AS location_name,
            u.username AS username
        FROM 
            inventory_checks ic
        JOIN 
            storage_locations sl ON ic.storage_location_id = sl.id
        LEFT JOIN 
            users u ON ic.created_by_user_id = u.id
        WHERE 
            ic.id = ?
    ");
    $stmt->execute([$check_id]);
    $check_info = $stmt->fetch();

    if (!$check_info) {
        header("Location: inventory_check.php");
        exit;
    }
} catch (PDOException $e) {
    $error = "获取盘点记录失败：" . $e->getMessage();
}

// 获取盘点明细
try {
    $stmt = $pdo->prepare("
        SELECT 
            ici.*,
            p.name AS product_name,
            p.specification,
            p.type AS product_type,
            p.unit
        FROM 
            inventory_check_items ici
        JOIN 
            products p ON ici.product_id = p.id
        WHERE 
            ici.inventory_check_id = ?
        ORDER BY 
            ABS(ici.difference) DESC, p.name
    ");
    $stmt->execute([$check_id]);
    $check_items = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取盘点明细失败：" . $e->getMessage();
}

// 统计分析
$total_products = count($check_items);
$discrepancy_count = 0;
$positive_diff = 0;
$negative_diff = 0;

foreach ($check_items as $item) {
    if ($item['difference'] != 0) {
        $discrepancy_count++;
        if ($item['difference'] > 0) {
            $positive_diff++;
        } else {
            $negative_diff++;
        }
    }
}

// 产品类型映射
$product_type_map = [
    'raw' => '原料',
    'semi-finished' => '半成品',
    'finished' => '成品'
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>盘点记录详情 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 通用样式 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 信息网格样式 */
        .info-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 20px;
            margin-bottom: 20px;
        }

        .info-item {
            background: #f9f9f9;
            padding: 15px;
            border-radius: 8px;
            border: 1px solid #eee;
        }

        .info-item h4 {
            margin-top: 0;
            margin-bottom: 10px;
            color: #555;
            font-size: 14px;
            font-weight: bold;
        }

        .info-value {
            font-size: 16px;
            font-weight: bold;
            color: #333;
        }

        /* 统计容器样式 */
        .stats-container {
            display: flex;
            gap: 20px;
            flex-wrap: wrap;
            margin-bottom: 20px;
        }

        .stat-box {
            flex: 1;
            min-width: 150px;
            background: #fff;
            padding: 15px;
            border-radius: 8px;
            text-align: center;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            border: 1px solid #eee;
            transition: transform 0.2s;
        }

        .stat-box:hover {
            transform: translateY(-3px);
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            margin-bottom: 8px;
        }

        .stat-label {
            color: #666;
            font-size: 14px;
        }

        /* 颜色样式 */
        .positive {
            color: #28a745;
        }

        .negative {
            color: #dc3545;
        }

        .neutral {
            color: #007bff;
        }

        /* 返回按钮样式 */
        .btn-back {
            display: inline-block;
            margin-bottom: 20px;
            padding: 10px 20px;
            background: #6c757d;
            color: white;
            text-decoration: none;
            border-radius: 4px;
            font-weight: bold;
            transition: all 0.3s;
        }

        .btn-back:hover {
            background: #5a6268;
            transform: translateY(-2px);
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        /* 表格样式 */
        .table-scroll {
            overflow-x: auto;
            margin-top: 20px;
            background: white;
            border-radius: 6px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            border: 1px solid #e5e5e5;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            font-size: 14px;
        }

        table th,
        table td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }

        table th {
            background-color: #f8f9fa;
            color: #333;
            font-weight: bold;
            position: sticky;
            top: 0;
        }

        table tr:last-child td {
            border-bottom: none;
        }

        table tr:hover {
            background-color: #f6f9fc;
        }

        /* 警告行样式 */
        .warning-row {
            background-color: #fff3cd !important;
        }

        .warning-row:hover {
            background-color: #ffeeba !important;
        }

        /* 处理建议样式 */
        .suggestions ul {
            padding-left: 20px;
        }

        .suggestions li {
            margin-bottom: 10px;
            line-height: 1.5;
        }

        .suggestions strong {
            color: #444;
        }

        .suggestions ul ul {
            margin-top: 8px;
            margin-bottom: 8px;
        }

        .suggestions ul ul li {
            margin-bottom: 5px;
            color: #555;
        }

        /* 警告样式 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        /* 动画效果 */
        @keyframes fadeIn {
            from {
                opacity: 0;
            }

            to {
                opacity: 1;
            }
        }

        .section {
            animation: fadeIn 0.5s;
        }
    </style>
</head>

<body>
    <div class="content">
        <a href="inventory_check.php" class="btn-back">
            <i class="fa fa-arrow-left"></i> 返回盘点列表
        </a>

        <h1>盘点记录详情</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <div class="section">
            <h2>盘点基本信息</h2>
            <div class="info-grid">
                <div class="info-item">
                    <h4>批次号</h4>
                    <div class="info-value"><?= htmlspecialchars($check_info['batch_number']) ?></div>
                </div>

                <div class="info-item">
                    <h4>盘点日期</h4>
                    <div class="info-value"><?= htmlspecialchars($check_info['check_date']) ?></div>
                </div>

                <div class="info-item">
                    <h4>盘点仓库</h4>
                    <div class="info-value"><?= htmlspecialchars($check_info['location_name']) ?></div>
                </div>

                <div class="info-item">
                    <h4>盘点人员</h4>
                    <div class="info-value"><?= htmlspecialchars($check_info['username']) ?></div>
                </div>

                <div class="info-item">
                    <h4>创建时间</h4>
                    <div class="info-value"><?= htmlspecialchars($check_info['created_at']) ?></div>
                </div>
            </div>

            <?php if (!empty($check_info['notes'])): ?>
                <div class="info-item" style="margin-top:20px;">
                    <h4>盘点备注</h4>
                    <div><?= nl2br(htmlspecialchars($check_info['notes'])) ?></div>
                </div>
            <?php endif; ?>
        </div>

        <div class="section">
            <h2>盘点统计</h2>
            <div class="stats-container">
                <div class="stat-box">
                    <div class="stat-value neutral"><?= $total_products ?></div>
                    <div class="stat-label">盘点产品总数</div>
                </div>

                <div class="stat-box">
                    <div class="stat-value <?= $discrepancy_count > 0 ? 'negative' : 'positive' ?>"><?= $discrepancy_count ?></div>
                    <div class="stat-label">差异产品数</div>
                </div>

                <div class="stat-box">
                    <div class="stat-value positive"><?= $positive_diff ?></div>
                    <div class="stat-label">盘盈产品数</div>
                </div>

                <div class="stat-box">
                    <div class="stat-value negative"><?= $negative_diff ?></div>
                    <div class="stat-label">盘亏产品数</div>
                </div>

                <div class="stat-box">
                    <div class="stat-value <?= $discrepancy_count > 0 ? 'negative' : 'positive' ?>">
                        <?= number_format($discrepancy_count > 0 ? ($discrepancy_count / $total_products * 100) : 0, 2) ?>%
                    </div>
                    <div class="stat-label">差异率</div>
                </div>
            </div>
        </div>

        <div class="section">
            <h2>盘点明细</h2>
            <div class="table-scroll">
                <table>
                    <thead>
                        <tr>
                            <th>产品名称</th>
                            <th>产品类型</th>
                            <th>规格</th>
                            <th>系统数量</th>
                            <th>实际数量</th>
                            <th>差异数量</th>
                            <th>单位</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($check_items as $item): ?>
                            <tr class="<?= $item['difference'] != 0 ? 'warning-row' : '' ?>">
                                <td><?= htmlspecialchars($item['product_name']) ?></td>
                                <td><?= isset($product_type_map[$item['product_type']]) ? $product_type_map[$item['product_type']] : $item['product_type'] ?></td>
                                <td><?= htmlspecialchars($item['specification']) ?></td>
                                <td><?= number_format($item['system_quantity'], 2) ?></td>
                                <td><?= number_format($item['actual_quantity'], 2) ?></td>
                                <td class="<?= $item['difference'] > 0 ? 'positive' : ($item['difference'] < 0 ? 'negative' : '') ?>">
                                    <?= number_format($item['difference'], 2) ?>
                                </td>
                                <td><?= htmlspecialchars($item['unit']) ?></td>
                                <td>
                                    <?php if ($item['difference'] > 0): ?>
                                        <span class="positive">盘盈</span>
                                    <?php elseif ($item['difference'] < 0): ?>
                                        <span class="negative">盘亏</span>
                                    <?php else: ?>
                                        <span class="neutral">正常</span>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <?php if ($discrepancy_count > 0): ?>
            <div class="section suggestions">
                <h2>差异处理建议</h2>
                <ul>
                    <li>对于<strong>盘亏</strong>产品，请检查：
                        <ul>
                            <li>是否存在未记录的出库操作</li>
                            <li>是否存在产品损耗未记录</li>
                            <li>是否存在操作人员失误</li>
                            <li>是否存在库存丢失情况</li>
                        </ul>
                    </li>
                    <li>对于<strong>盘盈</strong>产品，请检查：
                        <ul>
                            <li>是否存在入库记录未录入系统</li>
                            <li>是否存在重复入库情况</li>
                            <li>是否存在系统数据错误</li>
                        </ul>
                    </li>
                    <li>建议对差异较大的产品进行复盘核查，确认实际情况</li>
                    <li>根据实际情况，调整库存记录并进行相应账务处理</li>
                </ul>
            </div>
        <?php endif; ?>
    </div>
</body>

</html>