<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header('Content-Type: application/json');
    echo json_encode(['error' => '未登录或会话已过期']);
    exit;
}

// 设置响应类型为JSON
header('Content-Type: application/json');

// 检查ID参数
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    echo json_encode(['error' => '无效的发货单ID']);
    exit;
}

$id = (int)$_GET['id'];

try {
    // 从数据库获取发货单信息
    $stmt = $pdo->prepare("
        SELECT 
            s.*,
            so.order_number
        FROM 
            shipments s
        JOIN 
            sales_orders so ON s.sales_order_id = so.id
        WHERE 
            s.id = ?
    ");

    $stmt->execute([$id]);
    $shipment = $stmt->fetch();

    if (!$shipment) {
        echo json_encode(['error' => '未找到对应的发货单']);
        exit;
    }

    // 返回发货单信息
    echo json_encode($shipment);
} catch (PDOException $e) {
    echo json_encode(['error' => '获取数据失败: ' . $e->getMessage()]);
}
