<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化变量
$error = '';
$success = '';

// 检查表是否存在
try {
    // 先检查carriers表
    $stmt = $pdo->query("SHOW TABLES LIKE 'carriers'");
    if ($stmt->rowCount() == 0) {
        // 表不存在，查看SQL文件中的定义
        $sql_file = file_get_contents('../SQL/FruitEase.sql');

        // 提取carriers表的创建SQL
        if (preg_match('/CREATE TABLE\s+`carriers`\s*\((.*?)\)\s*ENGINE\s*=/s', $sql_file, $matches)) {
            $create_carriers_sql = "CREATE TABLE `carriers` (" . $matches[1] . ") ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '物流承运商信息表'";
            $pdo->exec($create_carriers_sql);

            // 提取INSERT语句
            if (preg_match('/INSERT INTO\s+`carriers`(.*?);/s', $sql_file, $insert_matches)) {
                $insert_carriers_sql = "INSERT INTO `carriers`" . $insert_matches[1];
                $pdo->exec($insert_carriers_sql);
            }
        } else {
            // 如果在SQL文件中找不到定义，则使用以下备用定义
            $pdo->exec("
                CREATE TABLE `carriers` (
                  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '物流公司ID',
                  `name` VARCHAR(100) NOT NULL COMMENT '公司名称',
                  `contact_person` VARCHAR(50) DEFAULT NULL COMMENT '联系人',
                  `phone` VARCHAR(20) DEFAULT NULL COMMENT '联系电话',
                  `service_type` VARCHAR(50) DEFAULT NULL COMMENT '服务类型 (例如: 快递, 专线物流, 冷链)',
                  `is_active` BOOLEAN DEFAULT TRUE COMMENT '是否合作',
                  PRIMARY KEY (`id`),
                  UNIQUE KEY `uk_carrier_name` (`name`)
                ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '物流承运商信息表'
            ");

            // 插入默认数据
            $pdo->exec("
                INSERT INTO
                  `carriers` (
                    `name`,
                    `contact_person`,
                    `phone`,
                    `service_type`
                  )
                VALUES
                  ('顺丰速运', '张经理', '95338', '快递, 冷链'),
                  ('德邦物流', '李主管', '95353', '专线物流, 大件运输'),
                  ('京东物流', '王先生', '950616', '快递, 仓配一体'),
                  ('本地冷链专线', '赵师傅', '13800138000', '冷链专线')
            ");
        }
    }
} catch (PDOException $e) {
    $error = "检查或创建数据表失败：" . $e->getMessage();
}

// 处理添加物流公司请求
if (isset($_POST['add_carrier'])) {
    $name = trim($_POST['name']);
    $contact_person = trim($_POST['contact_person']);
    $phone = trim($_POST['phone']);
    $service_type = trim($_POST['service_type']);

    try {
        $stmt = $pdo->prepare("
            INSERT INTO carriers (name, contact_person, phone, service_type, is_active)
            VALUES (?, ?, ?, ?, 1)
        ");

        $stmt->execute([$name, $contact_person, $phone, $service_type]);
        $success = "物流公司添加成功！";
    } catch (PDOException $e) {
        $error = "添加失败: " . $e->getMessage();
    }
}

// 处理编辑物流公司请求
if (isset($_POST['edit_carrier'])) {
    $id = (int)$_POST['id'];
    $name = trim($_POST['name']);
    $contact_person = trim($_POST['contact_person']);
    $phone = trim($_POST['phone']);
    $service_type = trim($_POST['service_type']);

    try {
        $stmt = $pdo->prepare("
            UPDATE carriers 
            SET name = ?, contact_person = ?, phone = ?, service_type = ?
            WHERE id = ?
        ");

        $stmt->execute([$name, $contact_person, $phone, $service_type, $id]);
        $success = "物流公司信息更新成功！";
    } catch (PDOException $e) {
        $error = "更新失败: " . $e->getMessage();
    }
}

// 处理停用/启用物流公司请求
if (isset($_GET['toggle_status'])) {
    $id = (int)$_GET['toggle_status'];
    $active = (isset($_GET['active']) && $_GET['active'] == 1) ? 1 : 0;

    try {
        $stmt = $pdo->prepare("UPDATE carriers SET is_active = ? WHERE id = ?");
        $stmt->execute([$active, $id]);
        $status_text = $active ? "启用" : "停用";
        $success = "物流公司已{$status_text}！";
    } catch (PDOException $e) {
        $error = "操作失败: " . $e->getMessage();
    }
}

// 获取物流公司列表
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$show_active_only = isset($_GET['active_only']) && $_GET['active_only'] == 1;

try {
    $query = "SELECT id, name, contact_person, phone, service_type, is_active FROM carriers WHERE 1=1";
    $params = [];

    if (!empty($search)) {
        $query .= " AND (name LIKE ? OR service_type LIKE ?)";
        $params[] = "%{$search}%";
        $params[] = "%{$search}%";
    }

    if ($show_active_only) {
        $query .= " AND is_active = 1";
    }

    $query .= " ORDER BY name";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $carriers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "查询数据时出错: " . $e->getMessage();
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>物流公司管理 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="content">
        <h1>物流公司管理</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <div class="filter-container">
            <div>
                <label>
                    <input type="checkbox" id="active-only" <?= $show_active_only ? 'checked' : '' ?>>
                    只显示激活
                </label>
            </div>

            <form class="search-box" action="" method="GET">
                <input type="text" name="search" placeholder="搜索物流公司名称或服务类型" value="<?= htmlspecialchars($search) ?>">
                <input type="hidden" name="active_only" id="active-only-param" value="<?= $show_active_only ? '1' : '0' ?>">
                <button type="submit">筛选</button>
            </form>

            <button class="btn-add" onclick="openAddModal()">添加物流公司</button>
        </div>

        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>物流公司名称</th>
                        <th>服务类型</th>
                        <th>联系人</th>
                        <th>联系电话</th>
                        <th>状态</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (empty($carriers)): ?>
                        <tr>
                            <td colspan="6" class="text-center">暂无物流公司记录</td>
                        </tr>
                    <?php else: ?>
                        <?php foreach ($carriers as $carrier): ?>
                            <tr>
                                <td><?= htmlspecialchars($carrier['name']) ?></td>
                                <td><?= htmlspecialchars($carrier['service_type']) ?></td>
                                <td><?= htmlspecialchars($carrier['contact_person'] ?: '-') ?></td>
                                <td><?= htmlspecialchars($carrier['phone'] ?: '-') ?></td>
                                <td>
                                    <span class="<?= $carrier['is_active'] ? 'active' : 'inactive' ?>">
                                        <?= $carrier['is_active'] ? '激活' : '停用' ?>
                                    </span>
                                </td>
                                <td class="action-buttons">
                                    <a href="javascript:void(0)" onclick="openEditModal(<?= $carrier['id'] ?>)" class="btn-edit">编辑</a>
                                    <?php if ($carrier['is_active']): ?>
                                        <a href="?toggle_status=<?= $carrier['id'] ?>&active=0" class="btn-delete" onclick="return confirm('确定要停用该物流公司吗?')">停用</a>
                                    <?php else: ?>
                                        <a href="?toggle_status=<?= $carrier['id'] ?>&active=1" class="btn-edit" onclick="return confirm('确定要激活该物流公司吗?')">激活</a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>

        <!-- 添加物流公司弹窗 -->
        <div id="addModal" class="modal">
            <div class="modal-content">
                <span class="close" onclick="closeModal('addModal')">&times;</span>
                <h3 class="modal-title">添加物流公司</h3>
                <form method="POST" action="">
                    <div class="form-group">
                        <label>公司名称</label>
                        <input type="text" name="name" required>
                    </div>
                    <div class="form-group">
                        <label>联系人</label>
                        <input type="text" name="contact_person">
                    </div>
                    <div class="form-group">
                        <label>联系电话</label>
                        <input type="text" name="phone">
                    </div>
                    <div class="form-group">
                        <label>服务类型</label>
                        <input type="text" name="service_type" placeholder="例如: 快递, 冷链, 专线物流">
                    </div>
                    <button type="submit" name="add_carrier">添加</button>
                </form>
            </div>
        </div>

        <!-- 编辑物流公司弹窗 -->
        <div id="editModal" class="modal">
            <div class="modal-content">
                <span class="close" onclick="closeModal('editModal')">&times;</span>
                <h3 class="modal-title">编辑物流公司</h3>
                <form method="POST" action="" id="editForm">
                    <input type="hidden" name="id" id="edit_id">
                    <div class="form-group">
                        <label>公司名称</label>
                        <input type="text" name="name" id="edit_name" required>
                    </div>
                    <div class="form-group">
                        <label>联系人</label>
                        <input type="text" name="contact_person" id="edit_contact_person">
                    </div>
                    <div class="form-group">
                        <label>联系电话</label>
                        <input type="text" name="phone" id="edit_phone">
                    </div>
                    <div class="form-group">
                        <label>服务类型</label>
                        <input type="text" name="service_type" id="edit_service_type">
                    </div>
                    <button type="submit" name="edit_carrier">保存</button>
                </form>
            </div>
        </div>

        <script>
            // 切换"只显示激活"参数
            document.getElementById('active-only').addEventListener('change', function() {
                document.getElementById('active-only-param').value = this.checked ? '1' : '0';
                document.querySelector('.search-box').submit();
            });

            // 打开添加弹窗
            function openAddModal() {
                document.getElementById('addModal').style.display = 'block';
            }

            // 打开编辑弹窗
            function openEditModal(id) {
                // 通过AJAX获取物流公司信息
                fetch('get_carrier.php?id=' + id)
                    .then(response => response.json())
                    .then(data => {
                        if (data.error) {
                            alert(data.error);
                            return;
                        }

                        // 填充表单
                        document.getElementById('edit_id').value = data.id;
                        document.getElementById('edit_name').value = data.name;
                        document.getElementById('edit_contact_person').value = data.contact_person || '';
                        document.getElementById('edit_phone').value = data.phone || '';
                        document.getElementById('edit_service_type').value = data.service_type || '';

                        // 显示弹窗
                        document.getElementById('editModal').style.display = 'block';
                    })
                    .catch(error => {
                        console.error('Error:', error);
                        alert('获取数据失败，请重试');
                    });
            }

            // 关闭弹窗
            function closeModal(modalId) {
                document.getElementById(modalId).style.display = 'none';
            }

            // 点击弹窗外部关闭
            window.onclick = function(event) {
                if (event.target.className === 'modal') {
                    event.target.style.display = 'none';
                }
            }
        </script>
    </div>
</body>

</html>