<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 检查必要的表是否存在
try {
    // 检查订单相关表是否存在并正常
    $stmt = $pdo->query("SHOW TABLES LIKE 'sales_orders'");
    if ($stmt->rowCount() == 0) {
        // 自动创建销售订单表
        try {
            $pdo->exec("
                CREATE TABLE `sales_orders` (
                  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '销售订单ID',
                  `order_number` VARCHAR(50) NOT NULL COMMENT '订单编号',
                  `customer_id` INT UNSIGNED NOT NULL COMMENT '客户ID',
                  `sales_channel_id` INT UNSIGNED DEFAULT NULL COMMENT '销售渠道ID',
                  `order_date` DATETIME NOT NULL COMMENT '订单日期时间',
                  `required_date` DATE DEFAULT NULL COMMENT '要求交货日期',
                  `total_amount` DECIMAL(12, 2) DEFAULT NULL COMMENT '订单总金额',
                  `status` ENUM('draft', 'confirmed', 'processing', 'partially_shipped', 'shipped', 'delivered', 'cancelled') NOT NULL DEFAULT 'draft' COMMENT '订单状态',
                  `shipping_address` VARCHAR(255) DEFAULT NULL COMMENT '收货地址',
                  `notes` TEXT DEFAULT NULL COMMENT '订单备注',
                  `created_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '创建人ID',
                  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                  PRIMARY KEY (`id`),
                  UNIQUE KEY `uk_sales_order_number` (`order_number`),
                  KEY `idx_so_customer` (`customer_id`),
                  KEY `idx_so_channel` (`sales_channel_id`),
                  KEY `idx_so_status` (`status`),
                  KEY `idx_so_order_date` (`order_date`)
                ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='销售订单主表'
            ");

            $success = "已自动创建销售订单表";

            // 检查sales_order_items表是否存在
            $stmt = $pdo->query("SHOW TABLES LIKE 'sales_order_items'");
            if ($stmt->rowCount() == 0) {
                // 自动创建销售订单项目表
                $pdo->exec("
                    CREATE TABLE `sales_order_items` (
                      `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '订单项ID',
                      `sales_order_id` INT UNSIGNED NOT NULL COMMENT '订单ID',
                      `product_id` INT UNSIGNED NOT NULL COMMENT '产品ID',
                      `quantity` DECIMAL(10,2) NOT NULL COMMENT '数量',
                      `unit_price` DECIMAL(10,2) NOT NULL COMMENT '单价',
                      `discount` DECIMAL(10,2) DEFAULT 0.00 COMMENT '折扣',
                      `subtotal` DECIMAL(10,2) NOT NULL COMMENT '小计',
                      `notes` VARCHAR(255) DEFAULT NULL COMMENT '备注',
                      PRIMARY KEY (`id`),
                      KEY `idx_order_item_order` (`sales_order_id`),
                      KEY `idx_order_item_product` (`product_id`),
                      CONSTRAINT `fk_order_item_order` FOREIGN KEY (`sales_order_id`) REFERENCES `sales_orders` (`id`) ON DELETE CASCADE
                    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='销售订单项目表'
                ");
                $success .= "<br>已自动创建销售订单项目表";
            }

            // 检查sales_channels表是否存在
            $stmt = $pdo->query("SHOW TABLES LIKE 'sales_channels'");
            if ($stmt->rowCount() == 0) {
                // 自动创建销售渠道表
                $pdo->exec("
                    CREATE TABLE `sales_channels` (
                      `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '渠道ID',
                      `name` VARCHAR(100) NOT NULL COMMENT '渠道名称',
                      `type` ENUM('online', 'offline', 'wholesale', 'ecommerce') NOT NULL DEFAULT 'offline' COMMENT '渠道类型',
                      `description` TEXT DEFAULT NULL COMMENT '渠道描述',
                      `status` TINYINT NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
                      `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                      `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                      PRIMARY KEY (`id`),
                      UNIQUE KEY `uk_channel_name` (`name`)
                    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='销售渠道表'
                ");

                // 添加默认销售渠道
                $pdo->exec("
                    INSERT INTO `sales_channels` (`name`, `type`, `description`, `status`) VALUES
                    ('线下门店', 'offline', '实体门店销售', 1),
                    ('官方网站', 'online', '公司官网在线销售', 1),
                    ('批发渠道', 'wholesale', '对企业和经销商的批发销售', 1),
                    ('电商平台', 'ecommerce', '第三方电商平台销售', 1)
                ");

                $success .= "<br>已自动创建销售渠道表并添加默认渠道";
            }

            // 检查customers表是否存在
            $stmt = $pdo->query("SHOW TABLES LIKE 'customers'");
            if ($stmt->rowCount() == 0) {
                // 自动创建客户表
                $pdo->exec("
                    CREATE TABLE `customers` (
                      `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '客户ID',
                      `name` VARCHAR(100) NOT NULL COMMENT '客户名称',
                      `type` ENUM('individual', 'company', 'distributor') NOT NULL DEFAULT 'individual' COMMENT '客户类型',
                      `contact_person` VARCHAR(50) DEFAULT NULL COMMENT '联系人',
                      `phone` VARCHAR(20) DEFAULT NULL COMMENT '联系电话',
                      `email` VARCHAR(100) DEFAULT NULL COMMENT '电子邮箱',
                      `address` TEXT DEFAULT NULL COMMENT '地址',
                      `status` TINYINT NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
                      `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                      `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                      PRIMARY KEY (`id`),
                      KEY `idx_customer_name` (`name`),
                      KEY `idx_customer_type` (`type`),
                      KEY `idx_customer_phone` (`phone`)
                    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='客户表'
                ");

                // 添加默认客户
                $pdo->exec("
                    INSERT INTO `customers` (`name`, `type`, `contact_person`, `phone`, `email`, `address`, `status`) VALUES
                    ('散客', 'individual', NULL, NULL, NULL, NULL, 1),
                    ('线上客户', 'individual', NULL, NULL, NULL, NULL, 1),
                    ('示例公司客户', 'company', '张经理', '13800138000', 'example@company.com', '北京市朝阳区', 1),
                    ('示例经销商', 'distributor', '李总', '13900139000', 'distributor@example.com', '上海市浦东新区', 1)
                ");

                $success .= "<br>已自动创建客户表并添加默认客户";
            }
        } catch (PDOException $e) {
            $error = "创建销售订单相关表失败：" . $e->getMessage();
        }
    } else {
        // 检查sales_orders表结构，确保有需要的字段
        $stmt = $pdo->query("SHOW COLUMNS FROM sales_orders");
        $columns = $stmt->fetchAll(PDO::FETCH_COLUMN);

        // 检查并添加缺失的字段
        $missingColumns = [];

        // 检查order_type字段
        if (!in_array('order_type', $columns)) {
            $missingColumns[] = "ADD COLUMN order_type ENUM('online', 'offline', 'wholesale', 'ecommerce') NOT NULL DEFAULT 'offline' COMMENT '订单类型'";
        }

        // 检查payment_status字段
        if (!in_array('payment_status', $columns)) {
            $missingColumns[] = "ADD COLUMN payment_status ENUM('pending', 'paid', 'partially_paid', 'refunded') NOT NULL DEFAULT 'pending' COMMENT '支付状态'";
        }

        // 如果有缺失的字段，自动添加
        if (!empty($missingColumns)) {
            try {
                $alterQuery = "ALTER TABLE sales_orders " . implode(", ", $missingColumns);
                $pdo->exec($alterQuery);
                $success = "已自动添加缺失字段到sales_orders表";
            } catch (PDOException $e) {
                $error = "添加缺失字段失败：" . $e->getMessage();
            }
        }
    }
} catch (PDOException $e) {
    $error = "检查数据表失败：" . $e->getMessage();
}

// 获取查询参数
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$order_status = isset($_GET['order_status']) ? $_GET['order_status'] : '';
$order_type = isset($_GET['order_type']) ? $_GET['order_type'] : '';
$channel_id = isset($_GET['channel_id']) ? (int)$_GET['channel_id'] : 0;
$date_from = isset($_GET['date_from']) ? $_GET['date_from'] : '2024-01-01';
$date_to = isset($_GET['date_to']) ? $_GET['date_to'] : '2025-12-31';

// 获取销售渠道
try {
    $stmt = $pdo->query("SELECT id, name, type FROM sales_channels ORDER BY name");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取销售渠道失败：" . $e->getMessage();
}

// 初始化变量
$orders = [];
$error = '';
$success = '';

// 查询订单列表
try {
    // 首先检查customers表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'customers'");
    if ($stmt->rowCount() == 0) {
        throw new Exception("客户表不存在，请先创建客户表");
    }

    // 检查所有需要使用的字段是否存在
    $required_tables_columns = [
        'sales_orders' => ['id', 'order_number', 'order_date', 'order_type', 'status', 'total_amount', 'payment_status'],
        'customers' => ['name', 'type', 'phone'],
        'sales_channels' => ['name']
    ];

    foreach ($required_tables_columns as $table => $columns) {
        // 检查表是否存在
        $stmt = $pdo->query("SHOW TABLES LIKE '$table'");
        if ($stmt->rowCount() == 0) {
            throw new Exception("表 $table 不存在，请刷新页面自动创建");
        }

        // 获取表的实际列
        $stmt = $pdo->query("SHOW COLUMNS FROM $table");
        $actual_columns = $stmt->fetchAll(PDO::FETCH_COLUMN);

        // 检查必要的列是否存在
        $missing_columns = array_diff($columns, $actual_columns);
        if (!empty($missing_columns)) {
            throw new Exception("表 $table 缺少必要的列: " . implode(', ', $missing_columns));
        }
    }

    $where_conditions = ["1=1"]; // 始终为真的条件，方便后续添加条件
    $params = [];

    if (!empty($search)) {
        $where_conditions[] = "(so.order_number LIKE ? OR c.name LIKE ? OR c.phone LIKE ?)";
        $search_param = "%$search%";
        $params[] = $search_param;
        $params[] = $search_param;
        $params[] = $search_param;
    }

    if (!empty($order_status)) {
        $where_conditions[] = "so.status = ?";
        $params[] = $order_status;
    }

    if (!empty($order_type)) {
        $where_conditions[] = "so.order_type = ?";
        $params[] = $order_type;
    }

    if ($channel_id > 0) {
        $where_conditions[] = "so.sales_channel_id = ?";
        $params[] = $channel_id;
    }

    if (!empty($date_from)) {
        $where_conditions[] = "so.order_date >= ?";
        $params[] = $date_from;
    }

    if (!empty($date_to)) {
        $where_conditions[] = "so.order_date <= ?";
        $params[] = $date_to;
    }

    $where_clause = implode(" AND ", $where_conditions);

    // 添加测试代码，调试所有字段
    try {
        $columns_check = $pdo->query("DESCRIBE sales_orders");
        $valid_columns = $columns_check->fetchAll(PDO::FETCH_COLUMN);
        $debug_info = "sales_orders表有效列: " . implode(', ', $valid_columns);
        // 仅在调试模式下显示
        if (isset($_GET['debug']) && $_GET['debug'] == 1) {
            $success .= "<br>" . $debug_info;
        }
    } catch (PDOException $e) {
        // 仅在调试模式下显示
        if (isset($_GET['debug']) && $_GET['debug'] == 1) {
            $error .= "<br>字段检查失败: " . $e->getMessage();
        }
    }

    // 构建安全的查询，只使用已确认存在的字段
    $query = "
        SELECT 
            so.id,
            so.order_number,
            so.order_date,
            so.order_type,
            so.status,
            so.total_amount,
            so.payment_status,
            c.name AS customer_name,
            c.type AS customer_type,
            sc.name AS channel_name,
            COUNT(soi.id) AS items_count
        FROM 
            sales_orders so
        LEFT JOIN 
            customers c ON so.customer_id = c.id
        LEFT JOIN 
            sales_channels sc ON so.sales_channel_id = sc.id
        LEFT JOIN 
            sales_order_items soi ON so.id = soi.sales_order_id
        WHERE 
            $where_clause
        GROUP BY 
            so.id
        ORDER BY 
            so.order_date DESC, so.id DESC
        LIMIT 100
    ";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $orders = $stmt->fetchAll();
} catch (Exception $e) {
    $error = "查询订单列表失败：" . $e->getMessage();
    // 输出详细错误信息用于调试
    if (isset($_SESSION['role_id']) && $_SESSION['role_id'] == 1) {
        $error .= "<br>SQL错误详情: " . $e->getMessage();
    }
    $orders = []; // 确保$orders变量有定义
}

// 订单状态映射
$order_status_map = [
    'pending' => '待处理',
    'processing' => '处理中',
    'completed' => '已完成',
    'cancelled' => '已取消'
];

// 订单类型映射
$order_type_map = [
    'online' => '线上订单',
    'offline' => '线下订单',
    'wholesale' => '批发订单',
    'ecommerce' => '电商订单'
];

// 支付状态映射
$payment_status_map = [
    'pending' => '待支付',
    'paid' => '已支付',
    'partially_paid' => '部分支付',
    'refunded' => '已退款'
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单管理 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 表单样式优化 */
        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #555;
            font-size: 14px;
        }

        /* 搜索表单样式 */
        .search-form {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(220px, 1fr));
            gap: 15px;
            align-items: end;
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 6px;
            border: 1px solid #eee;
            margin-bottom: 20px;
        }

        /* 消息样式 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>订单管理</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>
        <div class="form-group">
            <button type="button" onclick="window.location.href='order_create.php'" class="btn-primary">新建订单</button>
        </div>
        <div class="section">
            <h2>订单查询</h2>
            <form method="GET" action="" class="search-form">

                <div class="form-group">
                    <label for="search">搜索关键词:</label>
                    <input type="text" id="search" name="search" value="<?= htmlspecialchars($search) ?>" placeholder="订单号/客户名称/电话">
                </div>

                <div class="form-group">
                    <label for="order_type">订单类型:</label>
                    <select id="order_type" name="order_type">
                        <option value="">全部类型</option>
                        <option value="online" <?= $order_type == 'online' ? 'selected' : '' ?>>线上订单</option>
                        <option value="offline" <?= $order_type == 'offline' ? 'selected' : '' ?>>线下订单</option>
                        <option value="wholesale" <?= $order_type == 'wholesale' ? 'selected' : '' ?>>批发订单</option>
                        <option value="ecommerce" <?= $order_type == 'ecommerce' ? 'selected' : '' ?>>电商订单</option>
                    </select>
                </div>

                <div class="form-group">
                    <label for="order_status">订单状态:</label>
                    <select id="order_status" name="order_status">
                        <option value="">全部状态</option>
                        <option value="pending" <?= $order_status == 'pending' ? 'selected' : '' ?>>待处理</option>
                        <option value="processing" <?= $order_status == 'processing' ? 'selected' : '' ?>>处理中</option>
                        <option value="completed" <?= $order_status == 'completed' ? 'selected' : '' ?>>已完成</option>
                        <option value="cancelled" <?= $order_status == 'cancelled' ? 'selected' : '' ?>>已取消</option>
                    </select>
                </div>

                <div class="form-group">
                    <label for="channel_id">销售渠道:</label>
                    <select id="channel_id" name="channel_id">
                        <option value="">全部渠道</option>
                        <?php foreach ($channels as $channel): ?>
                            <option value="<?= $channel['id'] ?>" <?= $channel_id == $channel['id'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($channel['name']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label for="date_from">起始日期:</label>
                    <input type="date" id="date_from" name="date_from" value="<?= $date_from ?>">
                </div>

                <div class="form-group">
                    <label for="date_to">结束日期:</label>
                    <input type="date" id="date_to" name="date_to" value="<?= $date_to ?>">
                </div>

                <div class="form-group">
                    <button type="submit">查询订单</button>
                </div>


            </form>
        </div>

        <div class="section">
            <h2>订单列表</h2>
            <div class="table-container">
                <?php if (empty($orders)): ?>
                    <div class="empty-state">
                        <p>没有符合条件的订单记录</p>
                    </div>
                <?php else: ?>
                    <table>
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>下单日期</th>
                                <th>客户名称</th>
                                <th>订单类型</th>
                                <th>销售渠道</th>
                                <th>订单金额</th>
                                <th>订单状态</th>
                                <th>支付状态</th>
                                <th>商品数量</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($orders as $order): ?>
                                <tr>
                                    <td><?= htmlspecialchars($order['order_number']) ?></td>
                                    <td><?= date('Y-m-d', strtotime($order['order_date'])) ?></td>
                                    <td><?= htmlspecialchars($order['customer_name']) ?></td>
                                    <td><?= isset($order_type_map[$order['order_type']]) ? $order_type_map[$order['order_type']] : $order['order_type'] ?></td>
                                    <td><?= htmlspecialchars($order['channel_name']) ?></td>
                                    <td>¥<?= number_format($order['total_amount'], 2) ?></td>
                                    <td>
                                        <span class="status-tag <?= $order['status'] ?>">
                                            <?= isset($order_status_map[$order['status']]) ? $order_status_map[$order['status']] : $order['status'] ?>
                                        </span>
                                    </td>
                                    <td>
                                        <span class="<?= $order['payment_status'] == 'paid' ? 'positive' : ($order['payment_status'] == 'pending' ? 'negative' : 'neutral') ?>">
                                            <?= isset($payment_status_map[$order['payment_status']]) ? $payment_status_map[$order['payment_status']] : $order['payment_status'] ?>
                                        </span>
                                    </td>
                                    <td><?= $order['items_count'] ?></td>
                                    <td>
                                        <a href="order_detail.php?id=<?= $order['id'] ?>" class="btn-link">查看详情</a>
                                        <?php if ($order['status'] == 'pending'): ?>
                                            | <a href="order_process.php?id=<?= $order['id'] ?>" class="btn-link">处理订单</a>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        </div>

        <div class="section">
            <h2>订单统计</h2>
            <div class="stats-container">
                <div class="stats-card">
                    <div class="stats-item">
                        <div class="stats-value"><?= count($orders) ?></div>
                        <div class="stats-label">总订单数</div>
                    </div>

                    <div class="stats-item">
                        <div class="stats-value">
                            <?php
                            $pending_count = 0;
                            foreach ($orders as $order) {
                                if ($order['status'] == 'pending') $pending_count++;
                            }
                            echo $pending_count;
                            ?>
                        </div>
                        <div class="stats-label">待处理订单</div>
                    </div>

                    <div class="stats-item">
                        <div class="stats-value">
                            <?php
                            $total_amount = 0;
                            foreach ($orders as $order) {
                                $total_amount += $order['total_amount'];
                            }
                            echo '¥' . number_format($total_amount, 2);
                            ?>
                        </div>
                        <div class="stats-label">订单总金额</div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</body>

</html>